==> haskell-tasty-quickcheck-0.10.2-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.2
visibility:           public
id:                   tasty-quickcheck-0.10.2-9hnSS5TBsNAJXGp28qiC4g
key:                  tasty-quickcheck-0.10.2-9hnSS5TBsNAJXGp28qiC4g
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  635e4e4c2d1b08eafcfabec0340c0106
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-quickcheck-0.10.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-quickcheck-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.2-9hnSS5TBsNAJXGp28qiC4g
depends:
    QuickCheck-2.14.2-8j3zufNU5S8KwGTbQr1wl3 base-4.15.1.0
    optparse-applicative-0.16.1.0-7MkEW9mODN873jvtCcL34
    random-1.2.1.1-7hIjssL3s0vKltA9rBNATF
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.1-DCl5XvqxJs38DWw3R0pfhe

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.2-122-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-quickcheck
version:              0.10.2
visibility:           public
id:                   tasty-quickcheck-0.10.2-BQxDS1VD5LJ1I4qJ4gjTfs
key:                  tasty-quickcheck-0.10.2-BQxDS1VD5LJ1I4qJ4gjTfs
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/UnkindPartition/tasty
synopsis:             QuickCheck support for the Tasty test framework.
description:          QuickCheck support for the Tasty test framework.
category:             Testing
abi:                  8896cca725f55c44d394a9be5a520d73
exposed:              True
exposed-modules:      Test.Tasty.QuickCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-quickcheck-0.10.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-quickcheck-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-quickcheck
hs-libraries:         HStasty-quickcheck-0.10.2-BQxDS1VD5LJ1I4qJ4gjTfs
depends:
    QuickCheck-2.14.2-8j3zufNU5S8KwGTbQr1wl3 base-4.15.1.0
    optparse-applicative-0.16.1.0-3YmlKXRJwHQGqAOJ2fhTWh
    random-1.2.1.1-7hIjssL3s0vKltA9rBNATF
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR
    tasty-1.4.2.1-9M7Ltaafm27Je0oPJHxgsw

haddock-interfaces:
    /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
